@@ -509,7 +509,8 @@ def visualize_det_cv2_part(
     font = cv2.QT_FONT_NORMAL
     font_thickness = 1
     line_thickness = line_thickness
-
+    # font_color = (3, 3, 3)
+    font_color = (255, 255, 255)
     if transparent:
         img_mask = np.zeros_like(img)
 
@@ -640,7 +641,7 @@ def visualize_det_cv2_part(
                         txt_bottom_left,
                         font,
                         font_scale,
-                        (237, 237, 237),
+                        font_color,
                         font_thickness,
                         cv2.LINE_AA,
                     )
@@ -733,7 +734,7 @@ def visualize_det_cv2_part(
                     txt_bottom_left,
                     font,
                     font_scale,
-                    (237, 237, 237),
+                    font_color,
                     font_thickness,
                     cv2.LINE_AA,
                 )
@@ -750,7 +751,7 @@ def visualize_det_cv2_part(
         )
 
     if transparent:
-        img = cv2.addWeighted(img_mask, 0.9, img, 0.9, 0.9)
+        img = cv2.addWeighted(img_mask, 0.9, img, 0.99, 0.9)
 
     if is_show:
         cv2.imshow("image", img)
